% This script is an example of how to use the JavaRGSolve
% MATLAB wrapper for the rgsolve Java package.
%
% Richard M. Katzwer - August 8 2013
% rkatzwer@princeton.edu

%% SOLVING GAMES 
% In this cell we show how to write and solve the simple
% Cournot example from Abreu-Sannikov 2013

solver = JavaRGSolve();

% Construct the game primitives
G1 = [16, 3, 0; 21, 10, -1; 9, 5, -5];
G2 = [9, 13, 3; 1,4,0; 0 -4 -15];
delta = .3;
notes = 'Abreu Sannikov Simple Cournot Example';

% An rgsolve game object
game = solver.makeGame(G1, G2, delta, notes);

% get the solution to the game:
% this will print out information on the algorithm's
% iterations and pop out a GUI for exploring the game
% solution.
solution = solver.solve( game );

% we could also pass the game primitives directly to the 
% solver as follows:
%   solution = solver.solve( G1, G2, delta );
%   solution = solver.solve( G1, G2, delta, notes );

% A benefit of being in MATLAB is that we can call on its symbolic
% solver to explicitly solve the system of equations defining V*.
% To do this:
Vstar = solver.getExactSolution( solution )

% alternatively we could have written
%   command = solver.getExactSolutionCommand( solution );
%   V_star = eval( command )

%% EXPORTING AND LOADING GAMES:
% In this cell we show how to export a prisoners dilemma and then load
% it into the workspace.

solver = JavaRGSolve();

% write the game primitives
G1 = [2, -1; 3, 0]; G2 = G1'; delta = .75;

% we can export games to .mat files that can be imported
% by rgsolve.jar as follows.  This statement will bring
% up a file chooser for where to export the game to.
solver.exportGame( G1, G2, delta, notes );

% Calling this statement opens a file chooser to open a previously
% saved .mat file with fields G1, G2, delta, notes.
newGame = solver.loadGame;